diff --git a/modules/svg/svg.go b/modules/svg/svg.go
index 071340764e..6db5c7109b 100644
--- a/modules/svg/svg.go
+++ b/modules/svg/svg.go
@@ -62,5 +62,5 @@ func RenderHTML(icon string, others ...interface{}) template.HTML {
}
return template.HTML(svgStr)
}
- return template.HTML("")
+ return ""
}
diff --git a/public/img/auth/azureadv2.svg b/public/img/auth/azureadv2.svg
deleted file mode 100644
index 7dbd8ea625..0000000000
--- a/public/img/auth/azureadv2.svg
+++ /dev/null
@@ -1 +0,0 @@
-
\ No newline at end of file
diff --git a/public/img/auth/gitea.svg b/public/img/auth/gitea.svg
deleted file mode 100644
index f9015a31bd..0000000000
--- a/public/img/auth/gitea.svg
+++ /dev/null
@@ -1 +0,0 @@
-
\ No newline at end of file
diff --git a/public/img/auth/github.svg b/public/img/auth/github.svg
deleted file mode 100644
index 0e5bf3b4d6..0000000000
--- a/public/img/auth/github.svg
+++ /dev/null
@@ -1 +0,0 @@
-
\ No newline at end of file
diff --git a/public/img/auth/gitlab.svg b/public/img/auth/gitlab.svg
deleted file mode 100644
index 742370ac9a..0000000000
--- a/public/img/auth/gitlab.svg
+++ /dev/null
@@ -1 +0,0 @@
-
\ No newline at end of file
diff --git a/public/img/svg/gitea-azuread.svg b/public/img/svg/gitea-azuread.svg
new file mode 100644
index 0000000000..36845b7ee3
--- /dev/null
+++ b/public/img/svg/gitea-azuread.svg
@@ -0,0 +1 @@
+
\ No newline at end of file
diff --git a/public/img/svg/gitea-azureadv2.svg b/public/img/svg/gitea-azureadv2.svg
new file mode 100644
index 0000000000..a5fa73a76c
--- /dev/null
+++ b/public/img/svg/gitea-azureadv2.svg
@@ -0,0 +1 @@
+
\ No newline at end of file
diff --git a/public/img/svg/gitea-bitbucket.svg b/public/img/svg/gitea-bitbucket.svg
new file mode 100644
index 0000000000..7794df3d29
--- /dev/null
+++ b/public/img/svg/gitea-bitbucket.svg
@@ -0,0 +1 @@
+
\ No newline at end of file
diff --git a/public/img/svg/gitea-discord.svg b/public/img/svg/gitea-discord.svg
new file mode 100644
index 0000000000..5397e30ca5
--- /dev/null
+++ b/public/img/svg/gitea-discord.svg
@@ -0,0 +1 @@
+
\ No newline at end of file
diff --git a/public/img/svg/gitea-dropbox.svg b/public/img/svg/gitea-dropbox.svg
new file mode 100644
index 0000000000..bbcbdb6341
--- /dev/null
+++ b/public/img/svg/gitea-dropbox.svg
@@ -0,0 +1 @@
+
\ No newline at end of file
diff --git a/public/img/svg/gitea-facebook.svg b/public/img/svg/gitea-facebook.svg
new file mode 100644
index 0000000000..497c565299
--- /dev/null
+++ b/public/img/svg/gitea-facebook.svg
@@ -0,0 +1 @@
+
\ No newline at end of file
diff --git a/public/img/svg/gitea-google.svg b/public/img/svg/gitea-google.svg
new file mode 100644
index 0000000000..95fa7a3761
--- /dev/null
+++ b/public/img/svg/gitea-google.svg
@@ -0,0 +1 @@
+
\ No newline at end of file
diff --git a/public/img/svg/gitea-mastodon.svg b/public/img/svg/gitea-mastodon.svg
new file mode 100644
index 0000000000..3511f097c9
--- /dev/null
+++ b/public/img/svg/gitea-mastodon.svg
@@ -0,0 +1 @@
+
\ No newline at end of file
diff --git a/public/img/svg/gitea-microsoftonline.svg b/public/img/svg/gitea-microsoftonline.svg
new file mode 100644
index 0000000000..84bea0305d
--- /dev/null
+++ b/public/img/svg/gitea-microsoftonline.svg
@@ -0,0 +1 @@
+
\ No newline at end of file
diff --git a/public/img/svg/gitea-nextcloud.svg b/public/img/svg/gitea-nextcloud.svg
new file mode 100644
index 0000000000..c28b620ccd
--- /dev/null
+++ b/public/img/svg/gitea-nextcloud.svg
@@ -0,0 +1 @@
+
\ No newline at end of file
diff --git a/public/img/svg/gitea-twitter.svg b/public/img/svg/gitea-twitter.svg
new file mode 100644
index 0000000000..16598dd43b
--- /dev/null
+++ b/public/img/svg/gitea-twitter.svg
@@ -0,0 +1 @@
+
\ No newline at end of file
diff --git a/public/img/svg/gitea-yandex.svg b/public/img/svg/gitea-yandex.svg
new file mode 100644
index 0000000000..54ded7eb87
--- /dev/null
+++ b/public/img/svg/gitea-yandex.svg
@@ -0,0 +1 @@
+
\ No newline at end of file
diff --git a/services/auth/source/oauth2/providers_base.go b/services/auth/source/oauth2/providers_base.go
index c8e41430ab..5ba06febaf 100644
--- a/services/auth/source/oauth2/providers_base.go
+++ b/services/auth/source/oauth2/providers_base.go
@@ -3,7 +3,12 @@
package oauth2
-import "code.gitea.io/gitea/modules/setting"
+import (
+ "html/template"
+
+ "code.gitea.io/gitea/modules/log"
+ "code.gitea.io/gitea/modules/svg"
+)
// BaseProvider represents a common base for Provider
type BaseProvider struct {
@@ -21,14 +26,21 @@ func (b *BaseProvider) DisplayName() string {
return b.displayName
}
-// IconURL returns an icon path for this provider
-// Use svg for default icons, providers_openid has its own IconURL function
-func (b *BaseProvider) IconURL() string {
- name := b.name
- if b.name == "gplus" {
- name = "google"
+// IconHTML returns icon HTML for this provider
+func (b *BaseProvider) IconHTML() template.HTML {
+ svgName := "gitea-" + b.name
+ switch b.name {
+ case "gplus":
+ svgName = "gitea-google"
+ case "github":
+ svgName = "octicon-mark-github"
}
- return setting.AppSubURL + "/assets/img/auth/" + name + ".svg"
+ svgHTML := svg.RenderHTML(svgName, 20, "gt-mr-3")
+ if svgHTML == "" {
+ log.Error("No SVG icon for oauth2 provider %q", b.name)
+ svgHTML = svg.RenderHTML("gitea-openid", 20, "gt-mr-3")
+ }
+ return svgHTML
}
// CustomURLSettings returns the custom url settings for this provider
diff --git a/services/auth/source/oauth2/providers_openid.go b/services/auth/source/oauth2/providers_openid.go
index c394058d6f..54530ae8a8 100644
--- a/services/auth/source/oauth2/providers_openid.go
+++ b/services/auth/source/oauth2/providers_openid.go
@@ -4,8 +4,11 @@
package oauth2
import (
+ "html/template"
+
"code.gitea.io/gitea/modules/log"
"code.gitea.io/gitea/modules/setting"
+ "code.gitea.io/gitea/modules/svg"
"github.com/markbates/goth"
"github.com/markbates/goth/providers/openidConnect"
@@ -24,9 +27,9 @@ func (o *OpenIDProvider) DisplayName() string {
return "OpenID Connect"
}
-// IconURL returns an icon path for this provider
-func (o *OpenIDProvider) IconURL() string {
- return setting.AppSubURL + "/assets/img/svg/gitea-openid.svg"
+// IconHTML returns icon HTML for this provider
+func (o *OpenIDProvider) IconHTML() template.HTML {
+ return svg.RenderHTML("gitea-openid", 20, "gt-mr-3")
}
// CreateGothProvider creates a GothProvider from this Provider
diff --git a/templates/user/auth/signin_inner.tmpl b/templates/user/auth/signin_inner.tmpl
index 22cb620bfe..504457f394 100644
--- a/templates/user/auth/signin_inner.tmpl
+++ b/templates/user/auth/signin_inner.tmpl
@@ -53,16 +53,16 @@
{{end}}
{{if and .OrderedOAuth2Names .OAuth2Providers}}
-
diff --git a/services/auth/source/oauth2/providers.go b/services/auth/source/oauth2/providers.go
index 0aa83ba494..16620fad6d 100644
--- a/services/auth/source/oauth2/providers.go
+++ b/services/auth/source/oauth2/providers.go
@@ -5,6 +5,9 @@ package oauth2
import (
"errors"
+ "fmt"
+ "html"
+ "html/template"
"net/url"
"sort"
@@ -19,7 +22,7 @@ import (
type Provider interface {
Name() string
DisplayName() string
- IconURL() string
+ IconHTML() template.HTML
CustomURLSettings() *CustomURLSettings
}
@@ -35,7 +38,7 @@ type GothProvider interface {
}
// AuthSourceProvider provides a provider for an AuthSource. Multiple auth sources could use the same registered GothProvider
// So each auth source should have its own DisplayName and IconURL for display.
// The Name is the GothProvider's name, to help to find the GothProvider to sign in.
// The DisplayName is the auth source config's name, site admin set it on the admin page, the IconURL can also be set there.
type AuthSourceProvider struct {
@@ -51,11 +54,14 @@ func (p *AuthSourceProvider) DisplayName() string {
return p.sourceName
}
-func (p *AuthSourceProvider) IconURL() string {
+func (p *AuthSourceProvider) IconHTML() template.HTML {
if p.iconURL != "" {
- return p.iconURL
+ img := fmt.Sprintf(``,
+ html.EscapeString(p.iconURL), html.EscapeString(p.DisplayName()),
+ )
+ return template.HTML(img)
}
- return p.GothProvider.IconURL()
+ return p.GothProvider.IconHTML()
}
// Providers contains the map of registered OAuth2 providers in Gitea (based on goth)
@@ -35,7 +38,7 @@ type GothProvider interface {
}
// AuthSourceProvider provides a provider for an AuthSource. Multiple auth sources could use the same registered GothProvider
-// So each auth source should have its own DisplayName and IconURL for display.
+// So each auth source should have its own DisplayName and IconHTML for display.
// The Name is the GothProvider's name, to help to find the GothProvider to sign in.
// The DisplayName is the auth source config's name, site admin set it on the admin page, the IconURL can also be set there.